@@ -23,6 +23,7 @@ import glob
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.files import readFile
+from calculate.lib.utils.tools import get_best_nearest_resolution
 import calculate.lib.utils.device as device
 from calculate.lib.utils.common import (getVideoFromXorgLog,
                                         getVideoFromXorgConf,
@@ -333,23 +334,27 @@ class VariableOsInstallFbResolution(ResolutionVariable):
     metavalue = "<width>x<height>"
     xorg_need = False
     fbres = True
+    fallback_resolution = "1024x768"
 
     def init(self):
         self.help = _("set the framebuffer resolution")
         self.label = _("Framebuffer resolution")
 
-    FBIOGET_VSCREENINFO = 0x4600
+    def using_kms(self):
+        drv = self.Get('install.os_install_x11_video_drv')
+        kms = self.Get('install.os_x11_kms_video_drv')
+        return drv in kms
 
     def get(self):
-        """Get current framebuffer resolution"""
+        x11res = self.Get('os_install_x11_resolution')
+        if self.using_kms():
+            return x11res
+        hwinfo = device.Hwinfo()
         try:
-            fbdev = os.open('/dev/fb0', os.O_RDONLY)
-            data = fcntl.ioctl(fbdev, self.FBIOGET_VSCREENINFO, " " * 8)
-            res = struct.unpack("II", data)
-            return "%sx%s" % (res[0], res[1])
-        except (IOError, OSError):
-            pass
-        return "1024x768"
+            return get_best_nearest_resolution(
+                x11res, hwinfo) or self.fallback_resolution
+        except device.HwinfoError:
+            return self.fallback_resolution
 
 class VariableClGrubImageHash(ReadonlyVariable):
     """
