@@ -29,6 +29,7 @@ from calculate.lib.variables.linux import Linux
 from calculate.install.distr import (Distributive, PartitionDistributive,
                                      DirectoryDistributive, DefaultMountPath,
                                      DistributiveError, FlashDistributive,
+                                     ArchiveDistributive,
                                      MultiPartitions, PxeDistributive)
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -315,6 +316,13 @@ class VariableClImageFilename(DistroRepository, Variable):
         """Set image file"""
         if self.Get('cl_action') == 'system' and not isoimage:
             raise VariableError(_("You need to select a distribution image"))
+        try:
+            d = Distributive.fromFile(isoimage)
+            if isinstance(d, ArchiveDistributive):
+                raise VariableError(_("Wrong image file"))
+        except DistributiveError:
+            pass
+
         imageData = Distributive().getInfo(isoimage)
         if not ("os_linux_shortname" in imageData and
                     imageData.get('os_linux_build', '') and
@@ -413,15 +421,21 @@ class VariableClImageLinuxShortname(DistroRepository, Variable):
     metavalue = "SYSTEM"
     opt = ['--os', '-s']
 
+
     def init(self):
         self.label = "%s %s" % (_("Filter"), _("by distribution"))
         self.help = _("select the operation system")
 
     def choice(self):
-        return [("", _("Not used"))] + \
-               sorted(map(lambda x: (x, self.getFullNameByShort(x)),
-                          self.dictLinuxName.keys()),
-                      key=itemgetter(1))
+        return [("", _("Not used"))] + [
+                ("CLD", "Calculate Linux Desktop KDE"),
+                ("CLDM", "Calculate Linux Desktop MATE"),
+                ("CLDX", "Calculate Linux Desktop XFCE"),
+                ("CLS", "Calculate Linux Scratch"),
+                ("CDS", "Calculate Directory Server"),
+                ("CSS", "Calculate Scratch Server"),
+                ("CMC", "Calculate Media Center"),
+            ]
 
     def humanReadable(self):
         return self.Get() or _("Not used")
