@@ -24,16 +24,14 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile, getProgPath, process,
                                        readLinesFile)
-from calculate.lib.utils.common import getPasswdUsers, getUserGroups, getGroups, \
-    CmdlineParams
+from calculate.lib.utils.common import (getPasswdUsers, getUserGroups,
+                                        getGroups, CmdlineParams)
 from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.lib.utils.device import getUdevDeviceInfo
+import calculate.lib.utils.device as device
 from calculate.lib.encrypt import sha256_crypt
-from calculate.core.server.admin import Admins
 from calculate.lib.variables.system import RootType
-from autopartition import SchemeOpt, SchemeDevices
 from calculate.lib.encrypt import get_shadow_hash, get_grub_hash
 from calculate.core.server.admin import Admins
 import calculate.lib.cl_ini_parser as cl_ini_parser
@@ -650,19 +648,16 @@ class VariableClInstallDevFrom(Variable):
         If device in calculate3.env dev_from not exists set ''
         """
         if value:
-            value = getUdevDeviceInfo(name=value).get('DEVNAME', value)
+            value = device.udev.get_device_info(
+                name=value).get('DEVNAME', value)
         if value in self.Get('os_disk_dev'):
             return value
         else:
             return ""
 
     def get(self):
-        if (self.Get('cl_autopartition_set') == 'on' and
-                    SchemeOpt.Update in self.Get('cl_autopartition_scheme')):
-            return self.Select('cl_autopartition_disk_dev',
-                               where='cl_autopartition_disk_scheme',
-                               eq=SchemeDevices.Root2,
-                               limit=1)
+        if self.Get('cl_autopartition_set') == 'on':
+            return self.Get('cl_autopartition_factory').dev_from
         return ""
 
 
@@ -871,68 +866,11 @@ class VariableOsInstallUefiSet(Variable):
     """
     Install in UEFI
     """
-    type = "bool"
-    opt = ['--uefi']
-
-    def init(self):
-        self.label = _("UEFI boot")
-        self.help = _("use UEFI boot")
-
     def get(self):
-        if self.Get('cl_autopartition_set') == 'on':
-            return self.Get('cl_autopartition_uefi_set')
+        if self.Get('os_install_uefi'):
+            return "on"
         else:
-            if self.Get('os_install_disk_efi') or \
-                            "/boot/efi" in self.Get('os_location_dest'):
-                if self.Get('os_install_arch_machine') == 'x86_64' and \
-                                self.Get('os_install_root_type') != 'flash':
-                    return self.Get('os_uefi_set')
-        return 'off'
-
-    def check(self, value):
-        if value == 'on':
-            if self.Get('os_uefi_set') == 'off' and \
-                            self.Get('os_install_root_type') == 'hdd':
-                raise VariableError(
-                    _("Your system must be loaded in UEFI for using this "
-                      "bootloader"))
-            if not 'gpt' in self.Get('os_device_table'):
-                raise VariableError(
-                    _("GPT is needed for using the UEFI bootloader"))
-            if not (self.Get('os_install_disk_efi') or
-                            "/boot/efi" in self.Get('os_location_dest')):
-                raise VariableError(
-                    _("A EF00 partition is needed for using "
-                      "the UEFI bootloader"))
-            if self.Get('os_install_arch_machine') != 'x86_64':
-                raise VariableError(
-                    _("Architecture of the target system must be x86_64"))
-            if self.Get('os_install_root_type') == 'flash':
-                raise VariableError(
-                    _("This option not used for Flash install"))
-
-    def uncompatible(self):
-        """
-        Uncompatible with autopartition
-        """
-        if self.Get('cl_autopartition_set') == "on":
-            return \
-                _("The layout is not available with autopartitioning")
-        if self.Get('os_install_root_type') == 'flash':
-            return \
-                _("This option not used for Flash install")
-        return ""
-
-
-class VariableOsInstallUefiBriefSet(VariableOsInstallUefiSet):
-    def uncompatible(self):
-        if self.Get('os_install_root_type') == 'flash':
-            return _("This option not used for Flash install")
-        return ""
-
-    def get(self):
-        return self.Get('os_install_uefi_set')
-
+            return "off"
 
 class VariableOsInstallGrubTerminal(Variable):
     """
